@@ -245,5 +245,5 @@ class MidiInstrument(Instrument):
 				"Applause", 
 				"Gunshot"]
 
-	def __init__(self):
-		pass
+	def __init__(self, name= ""):
+		self.name = name
